@@ -1,7 +1,7 @@
 //! microbit contains everything required to get started with the use of Rust
 //! to create firmwares for the fabulous [BBC micro:bit](https://microbit.org)
 //! microcontroller board.
-#![doc(html_root_url = "https://docs.rs/microbit-common/0.10.0")]
+#![doc(html_root_url = "https://docs.rs/microbit-common/0.11.0")]
 #![no_std]
 #![deny(missing_docs)]
 #![allow(non_camel_case_types)]
@@ -18,9 +18,11 @@ pub use nrf52833_hal as hal;
 pub use hal::pac;
 pub use hal::pac::Peripherals;
 
+pub mod board;
 pub mod display;
 pub mod gpio;
-pub mod led;
+
+pub use board::Board;
 
 #[cfg(feature = "v1")]
 mod v1;
